@@ -778,6 +778,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 		try:
 			seq = Options.get_sequencer(o)
+			seq.tick_function = self.sequencer_tick
 			self.ui.stopbutton.setEnabled(True)
 			self.ui.startbutton.setEnabled(False)
 			self.lastmidi = o.midifile
@@ -803,6 +804,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.ui.startbutton.setEnabled(True)
 		del self.seqthread
 
+	def sequencer_tick(self, state):
+		self.scene.paint_bar(state["bar"])
+
 
 class SequencerThread(QtCore.QThread):
 	def __init__(self, seq):
